==> sumo_1.24.0+dfsg2.orig.tar.xz: sumo-1_24_0/tests/netedit/network/junctions/inspect/no_tls/unselected/pos/merge/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2025 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys
import time

sys.path.append(os.path.join(os.environ.get("SUMO_HOME", "."), "tools"))
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart()

# rebuild network
netedit.computeJunctions()

# inspect central node
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.center)

# change position with a non valid value
netedit.modifyAttribute(netedit.attrs.junction.inspect.pos, "dummy position")

# change position with a non valid value (another junction in the same position)
netedit.modifyAttribute(netedit.attrs.junction.inspect.pos, "-25.00,0.00")

# wait for output
time.sleep(2)

# merge
netedit.typeKey("enter")

# wait for output
time.sleep(2)

# rebuild network
netedit.computeJunctions()

# Check undo
netedit.undo(referencePosition, 5)

# rebuild network
netedit.computeJunctions()

# Check redo
netedit.redo(referencePosition, 5)

# rebuild network
netedit.computeJunctions()

# save Netedit config
netedit.saveExistentShortcut("neteditConfig")

# type space
netedit.typeKey("space")

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.25.0+dfsg1.orig.tar.xz: sumo-1_25_0/tests/netedit/network/junctions/inspect/no_tls/unselected/pos/merge/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2025 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys
import time

sys.path.append(os.path.join(os.environ.get("SUMO_HOME", "."), "tools"))
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart()

# rebuild network
netedit.computeJunctions()

# inspect central node
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.center)

# change position with a non valid value
netedit.modifyAttribute(netedit.attrs.junction.inspect.pos, "dummy position")

# change position with a non valid value (another junction in the same position)
netedit.modifyAttribute(netedit.attrs.junction.inspect.pos, "-25.00,0.00")

# wait for output
time.sleep(2)

# merge
netedit.typeKey("enter")

# wait for output
time.sleep(2)

# rebuild network
netedit.computeJunctions()

# Check undo
netedit.undo(referencePosition, 5)

# rebuild network
netedit.computeJunctions()

# Check redo
netedit.redo(referencePosition, 5)

# rebuild network
netedit.computeJunctions()

# save Netedit config
netedit.saveExistentFile("neteditConfig")

# type space
netedit.typeKey("space")

# quit netedit
netedit.quit(neteditProcess)
